clear all;

% Initialization and read experimental data set for one particular test  (num)

g=9.81;
rho_s = 2500; % Beads density
rho_w = 1000; % Water density
phi_s = 23.3; % Beads internal friciton angle (deg.)
alpha = 35; % Slope angle (deg.)
Pack = 0.634; % Porosity for Random packing of sphere
width = 0.25; % Tank width
h_step = 0.207; % Bottom gate height over floor

xi=[];
num=input('test : ');
cas=2;
a=xlsread('Tests_landslide_matlab.xlsx','','','basic');
ind=find(a(:,1)==num);
h=a(ind,2)/1000  % Water depth (m)
D =a(ind,3)/1000  % Beads D (m)
M =a(ind,4) % Beads M (Kg)
sens=-a(ind,5:8);  % Gage calibration
eta=load(['essai' num2str(num) '.txt']);

% Plot wave gage data

t=eta(:,1)-eta(1,1);  % Time axis
etaf=zeros(size(eta,1),4);

for ii=1:4
    etaf(:,ii)=eta(:,2*ii)/sens(ii);
    etaf(:,ii)=etaf(:,ii)-mean(etaf(1:100,ii)); % Remove still water level
end;
[max_eta,indt]=max(etaf(:,1)); 
t0=t(indt);
figure(1)
for ii=1:4
    subplot(2,2,ii);
    plot(t,etaf(:,ii));
    xlim([t0-1.5 t0+7.5])
    ylim([min(min(etaf))*1.1 max(max(etaf))*1.1]);
    set(gca,'fontsize',12,'fontname','times');
    grid on;
    xlabel('time (s)'); ylabel('\eta (cm)');
end;

data = [t etaf(:,1) etaf(:,2) etaf(:,3) etaf(:,4)];
xlswrite('test.xlsx',data);  % Save test data as Matlab file

% Processing for computaitons

V_beads = (4/3) * pi * (D/2)^3; % Beads volume
n_beads = M/(rho_s * V_beads) % Nb. of beads
Vt_beads = n_beads * V_beads; % Beads total volume
Vt_slide = Vt_beads/Pack % Slide volume
Mp = M - rho_w * Vt_beads; % Mass under water
rho_a = rho_w + (M - 2*rho_w * Vt_beads)/Vt_slide % Apparent slide density
h_gate = sqrt(2 * Vt_slide * tand(alpha)/width) % Initial gate height
d = h - h_gate - h_step %  Slide top submergence
